@@ -4,7 +4,7 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint;
 
-our $VERSION = '0.1002'; # VERSION
+our $VERSION = '0.1003'; # VERSION
 # ABSTRACT: Documentation from class metadata
 
 use Moose;
@@ -385,9 +385,24 @@ __END__
 
 Pod::Elemental::Transformer::Splint - Documentation from class metadata
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14-brightgreen.svg" alt="Requires Perl 5.14" /> <a href="https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint"><img src="https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14](https://img.shields.io/badge/perl-5.14-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master)](https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.1002, released 2015-01-18.
+Version 0.1003, released 2016-01-11.
 
 =head1 SYNOPSIS
 
@@ -595,7 +610,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
